
set more off
clear
use fem2
sjlog using ch3.10, replace
local anxlevel None Mild Moderate Severe 
display "The defined levels of anxiety are: `anxlevel'"
sjlog close, replace
// stripdot using ch3.10.log.tex

sjlog using ch3.11, replace
local count 0
local anxlevel None Mild Moderate Severe 
foreach a of local anxlevel {
   local count  `count' + 1
   display "Anxiety level `count' : `a'"
} 
sjlog close, replace
// stripdot using ch3.11.log.tex

sjlog using ch3.12, replace
local count 0
local anxlevel None Mild Moderate Severe 
foreach a of local anxlevel {
   local count = `count' + 1
   display "Anxiety level `count' : `a'"
} 
sjlog close, replace
// stripdot using ch3.12.log.tex

sjlog using ch3.13, replace
local count 0
local anxlevel None Mild Moderate Severe 
foreach a of local anxlevel {
   local count = `count' + 1
   local newlist "`newlist' `count' `a'"
} 
display "`newlist'"
sjlog close, replace
// stripdot using ch3.13.log.tex

/*
sjlog using ch3.13a, replace
local count 0
local anxlevel None Mild Moderate Severe 
foreach a of local anxlevel {
   display "Anxiety level `++count' : `a'"
} 
sjlog close, replace
stripdot using ch3.13a.log.tex
*/

sjlog using ch3.14, replace
local anxlevel None Mild Moderate Severe 
local wds: word count `anxlevel'
display "There are `wds' anxiety levels:"
forvalues i = 1/`wds' {
	local wd: word `i' of `anxlevel'
	display "Level `i' is `wd'"
}
sjlog close, replace
// stripdot using ch3.14.log.tex

sjlog using ch3.14a, replace
local anxlevel None Mild Moderate Severe
tokenize "`anxlevel'"
local wds: word count `anxlevel'
display "There are `wds' anxiety levels:"
forvalues i = 1/`wds' {
	display "Level `i' is ``i''"
}
sjlog close, replace
// stripdot using ch3.14a.log.tex

use fem2, clear
sjlog using ch3.15, replace
scalar root2 = sqrt(2.0)
generate double rootage = age * root2
sjlog close, replace
// stripdot using ch3.15.log.tex

sjlog using ch3.16, replace
use fem2, clear
scalar lb1 = 80
scalar ub1 = 88
scalar lb2 = 89
scalar ub2 = 97
scalar lb3 = 98
scalar ub3 = 109
forvalues i = 1/3 {
	display _n "IQ " lb`i' " - " ub`i'
	tabulate anxiety if inrange(iq, lb`i', ub`i') 
}
sjlog close, replace
// stripdot using ch3.16.log.tex

sjlog using ch3.17, replace
generate age2 = age^2
regress weight age age2
matrix b = e(b)
matrix V = e(V)
matrix list b 
matrix list V
sjlog close, replace
// stripdot using ch3.17.log.tex

sjlog using ch3.18, replace
matrix accum C = weight age iq, dev nocons
matrix Corr = corr(C)
matrix list Corr
sjlog close, replace
// stripdot using ch3.18.log.tex

sjlog using ch3.19, replace
quietly regress weight age age2
matrix V = e(V)
matrix cov = V[1,2]
matrix list cov
matrix cov2 = V["age","age2"]
matrix list cov2
sjlog close, replace
// stripdot using ch3.19.log.tex

sjlog using ch3.20, replace
statsmat iq if age < 35, by(anxiety) stat(N mean sd) matrix(iqanx1)
statsmat iq if age >= 35, by(anxiety) stat(N mean sd) matrix(iqanx2)
matrix result = iqanx1, iqanx2 
mat list result, ti("IQ by anxiety score for <35, >=35 years age") 
sjlog close, replace
// stripdot using ch3.20.log.tex
set more on

/*
use gdp4cty, clear
local country US UK DE FR
local cc 1
foreach c of local country {
	generate double `c'gdp = gdp`cc'
	local ++cc
	}

sjlog using appB.9a, replace
local country US UK DE FR
foreach c of local country {
	generate double lngdp`c' = log(`c'gdp)
	summarize lngdp`c' 
	}
sjlog close, replace

drop gdp
sjlog using appB.9b, replace
generate double gdptot = 0
foreach c of varlist *gdp {
	qui replace gdptot = gdptot + `c'
}
summarize *gdp gdptot
sjlog close, replace

use gdp4cty, clear
sjlog using appB.10, replace
forvalues y = 1995(2)1999 {
	forvalues i = 1/4 {
		summarize gdp`i'_`y' 
	}
}
sjlog close, replace

sysuse lifeexp,clear
sjlog using appB.11, replace
foreach v of varlist lexp-safewater {
	summarize `v'
	correlate popgrowth `v' 
	scatter popgrowth `v'
}
sjlog close, replace

use gdp4cty, clear
sjlog using appB.12, replace
local ctycode 111 112 136 134
local i 0
foreach c of local ctycode {
	local ++i
	local rc "`rc' (`i'=`c')"
}
display "`rc'"
recode cc `rc', gen(newcc)
tabulate newcc
sjlog close, replace

use gdp4cty, clear
sjlog using appB.13, replace
local country US UK DE FR
local yrlist 1995 1999
forvalues i = 1/4 {  
	local cname: word `i' of `country'
	foreach y of local yrlist {
		rename gdp`i'_`y' gdp`cname'_`y'
	}
}
summ gdpUS*
sjlog close, replace

sjlog using appB.14, replace
webuse abdata,clear
describe
return list
local sb: sortedby
display "dataset sorted by : `sb'"
sjlog close, replace

sjlog using appB.15, replace
summarize emp, detail
return list
scalar iqr = r(p75) - r(p25)
display "IQR = " iqr
scalar semean = r(sd)/sqrt(r(N))
display "Mean = " r(mean) " S.E. = " semean
sjlog close, replace

webuse abdata,clear
sjlog using appB.16, replace
tsset
return list
sjlog close, replace

sjlog using appB.17, replace
generate lowind = (ind<6)
ttest emp, by(lowind)
return list
sjlog close, replace

sjlog using appB.18, replace
regress emp wage cap
ereturn list
local regressors: colnames e(b)
display "Regressors: `regressors'"
sjlog close, replace

*/