* itsp ch9.01 - ch9.05c

set more off

/*
webuse grunfeld, clear
drop time
reshape wide invest mvalue kstock, i(year) j(company)
egen invavg = rowmean(invest*)
egen kapavg = rowmean(kstock*)
reshape long
tsset company year
save grunfeldavg, replace
*/



clear all
use grunfeldavg
sjlog using ch9.03, replace
levelsof company, local(colist)
local ncomp : word count `colist'
forvalues i = 1/`ncomp' {
	local c : word `i' of `colist'
	quietly regress invest L(1/2).kstock L.kapavg if company == `c'
	matrix beta`i' = e(b)
	matrix allbeta = (nullmat(allbeta) \ beta`i')
	local row "`row' `c'"
}
matrix rownames allbeta = `row'
sjlog close, replace
// stripdot using ch9.03.log.tex
	
sjlog using ch9.03a, replace
outtable using ch9.03t, mat(allbeta) replace ///
format(%9.4f) center caption("Grunfeld company estimates")
sjlog close, replace
// stripdot using ch9.03a.log.tex

sjlog using ch9.01, replace
use grunfeldavg, clear
levelsof company, local(colist)
local ncomp : word count `colist'
matrix table1 = J(`ncomp', 7, 0)
sjlog close, replace
// stripdot using ch9.01.log.tex

sjlog using ch9.01a, replace
local i 0
levelsof company, local(colist)
foreach c of local colist {
	quietly {
		local ++i
		summarize invest if company == `c', detail
		matrix table1[`i', 1] = r(p25)
		matrix table1[`i', 2] = r(p50)
		matrix table1[`i', 3] = r(p75)
		correlate invest invavg if company == `c'
		matrix table1[`i', 4] = r(rho)
		correlate kstock kapavg if company == `c'
		matrix table1[`i', 5] = r(rho)
		regress invest L.kstock L.kapavg if company == `c'
		matrix table1[`i', 6] = _b["L.kstock"]
		matrix table1[`i', 7] = _se["L.kstock"]
	}
}
matrix rownames table1 = `colist'
matrix colnames table1 = p25 p50 p75 r_invest r_kap beta_k se_k
sjlog close, replace
// stripdot using ch9.01a.log.tex

/*
sjlog using ch9.01a, replace
tokenize `colist'
forvalues i = 1/`ncomp' {
	quietly {
		summarize invest if company == ``i'', detail
		matrix table1[`i', 1] = r(p25)
		matrix table1[`i', 2] = r(p50)
		matrix table1[`i', 3] = r(p75)
		correlate invest invavg if company == ``i''
		matrix table1[`i', 4] = r(rho)
		correlate kstock kapavg if company == ``i''
		matrix table1[`i', 5] = r(rho)
		regress invest L.kstock L.kapavg if company == ``i''
		matrix table1[`i', 6] = _b["L.kstock"]
		matrix table1[`i', 7] = _se["L.kstock"]
	}
}
matrix rownames table1 = `colist'
matrix colnames table1 = p25 p50 p75 r_invest r_kap beta_k se_k
sjlog close, replace
*/
/*
sjlog using ch9.01a, replace
forvalues i = 1/`ncomp' {
	local c : word `i' of `colist'
	quietly {
		summarize invest if company == `c', detail
		matrix table1[`i', 1] = r(p25)
		matrix table1[`i', 2] = r(p50)
		matrix table1[`i', 3] = r(p75)
		correlate invest invavg if company == `c'
		matrix table1[`i', 4] = r(rho)
		correlate kstock kapavg if company == `c'
		matrix table1[`i', 5] = r(rho)
		regress invest L.kstock L.kapavg if company == `c'
		matrix table1[`i', 6] = _b["L.kstock"]
		matrix table1[`i', 7] = _se["L.kstock"]
	}
}
matrix rownames table1 = `colist'
matrix colnames table1 = p25 p50 p75 r_invest r_kap beta_k se_k
sjlog close, replace
*/

sjlog using ch9.02, replace
mat list table1, format(%9.3f) ti("Grunfeld company statistics")
sjlog close, replace
sjlog using ch9.02a, replace
outtable using ch9.02t, mat(table1) replace ///
format(%9.3f) center caption("Grunfeld company statistics")
sjlog close, replace
// stripdot using ch9.02.log.tex

sjlog using ch9.04, replace
use grunfeldavg, clear
levelsof company, local(colist)
local ncomp : word count `colist'
tempname p
postfile `p' compnr p25 p50 p75 r_invest r_kap beta_k se_k using firmstats, replace
sjlog close, replace
// stripdot using ch9.04.log.tex

sjlog using ch9.04a, replace
forvalues i = 1/`ncomp' {
	local c : word `i' of `colist'
	quietly {
		summarize invest if company == `c', detail
		local p25 = r(p25)
		local p50 = r(p50)
		local p75 = r(p75)
		correlate invest invavg if company == `c'
		local r_invest = r(rho)
		correlate kstock kapavg if company == `c'
		local r_kap = r(rho)
		regress invest L.kstock L.kapavg if company == `c'
	}
	post `p' (`i') (`p25') (`p50') (`p75') (`r_invest') (`r_kap') ///
	(_b["L.kstock"]) (_se["L.kstock"]) 
}
postclose `p'
sjlog close, replace
// stripdot using ch9.04a.log.tex

sjlog using ch9.04b, replace
use firmstats, clear
summarize
sjlog close, replace
// stripdot using ch9.04b.log.tex

sjlog using ch9.05, replace
tempname fh
file open `fh' using matout.raw, write replace
sjlog close, replace
// stripdot using ch9.05.log.tex

sjlog using ch9.05a, replace
local rows = rowsof(table1)
local cols = colsof(table1)
local timestamp "Matrix created `c(current_date)' `c(current_time)'"
file write `fh' "`timestamp'" _n
file write `fh' "`rows' `cols'" _n
forvalues i = 1/`rows' {
	forvalues j = 1/`cols' {
		file write `fh' (table1[`i', `j']) " "
	}
	file write `fh' _n
}
file close `fh'
sjlog close, replace
// stripdot using ch9.05a.log.tex

sjlog using ch9.05b, replace
tempname fh
file open `fh' using matout2.raw, write replace
local rows = rowsof(table1)
local cols = colsof(table1)
local timestamp "Matrix created `c(current_date)' `c(current_time)'"
file write `fh' "`timestamp'" _n
file write `fh' "`rows' `cols'" _n
local coln : colnames table1
local rown : rownames table1
file write `fh' "firmno `coln'" _n
forvalues i = 1/`rows' {
	local rn : word `i' of `rown'
	file write `fh' `"`rn' "'
	forvalues j = 1/`cols' {
		file write `fh' (table1[`i', `j']) " "
	}
	file write `fh' _n
}
file close `fh'
sjlog close, replace
// stripdot using ch9.05b.log.tex

sjlog using ch9.05c, replace
type matout2.raw
sjlog close, replace
// stripdot using ch9.05c.log.tex


/*

histogram p50, normal saving(fig7_2,replace) scheme(s2mono)
sjlog close, replace
graph display, xsize(4) ysize(3)
graph export fig7_2.eps, replace

*/